==> open-xchange-documents-backend_7.6.2.orig.tar.bz2: open-xchange-documents-backend-7.6.2/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/CTTablePartStyle.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_TablePartStyle complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_TablePartStyle">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="tcTxStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleTextStyle" minOccurs="0"/>
 *         &lt;element name="tcStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleCellStyle" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_TablePartStyle", propOrder = {
    "tcTxStyle",
    "tcStyle"
})
public class CTTablePartStyle {

    protected CTTableStyleTextStyle tcTxStyle;
    protected CTTableStyleCellStyle tcStyle;

    /**
     * Gets the value of the tcTxStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public CTTableStyleTextStyle getTcTxStyle() {
        return tcTxStyle;
    }

    /**
     * Sets the value of the tcTxStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public void setTcTxStyle(CTTableStyleTextStyle value) {
        this.tcTxStyle = value;
    }

    /**
     * Gets the value of the tcStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public CTTableStyleCellStyle getTcStyle() {
        return tcStyle;
    }

    /**
     * Sets the value of the tcStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public void setTcStyle(CTTableStyleCellStyle value) {
        this.tcStyle = value;
    }

}

==> open-xchange-documents-backend_7.10.6.orig.tar.bz2: open-xchange-documents-backend-7.10.6/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/CTTablePartStyle.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.Marshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_TablePartStyle complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_TablePartStyle">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="tcTxStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleTextStyle" minOccurs="0"/>
 *         &lt;element name="tcStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleCellStyle" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_TablePartStyle", propOrder = {
    "tcTxStyle",
    "tcStyle"
})
public class CTTablePartStyle {

    protected CTTableStyleTextStyle tcTxStyle;
    protected CTTableStyleCellStyle tcStyle;

    /**
     * Gets the value of the tcTxStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public CTTableStyleTextStyle getTcTxStyle(boolean forceCreate) {
    	if(tcTxStyle==null&&forceCreate) {
    		tcTxStyle = new CTTableStyleTextStyle();
    	}
        return tcTxStyle;
    }

    /**
     * Sets the value of the tcTxStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public void setTcTxStyle(CTTableStyleTextStyle value) {
        this.tcTxStyle = value;
    }

    /**
     * Gets the value of the tcStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public CTTableStyleCellStyle getTcStyle(boolean forceCreate) {
    	if(tcStyle==null&&forceCreate) {
    		tcStyle = new CTTableStyleCellStyle();
    	}
        return tcStyle;
    }

    /**
     * Sets the value of the tcStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public void setTcStyle(CTTableStyleCellStyle value) {
        this.tcStyle = value;
    }

    public boolean isEmpty() {
    	return (tcStyle==null||tcStyle.isEmpty())&&tcTxStyle==null;
    }

    public void beforeMarshal(Marshaller marshaller) {
    	if(tcStyle!=null&&tcStyle.isEmpty()) {
    		tcStyle = null;
    	}
    }
}
